yakumo.neutron.v2.lb.pool

Package yakumo :: Package neutron :: Package v2 :: Package lb :: Module pool |
[hide private]
[frames] | no frames]

# Module pool

source code

Resource class and its manager for LB Pools in Networking V2 API

Classes | [hide private]
| Resource Resource class for LB Pools in Networking V2 API
| Manager Manager class for LB Pools in Networking V2 API

Variables | [hide private]
| ATTRIBUTE_MAPPING = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass obj`...``
| __package__ = ``'``yakumo.neutron.v2.lb``'``

Variables Details | [hide private]

  ### ATTRIBUTE_MAPPING Value:
      [('id', 'id', mapper.Noop), ('name', 'name', mapper.Noop), ('descripti
      on', 'description', mapper.Noop), ('lb_method', 'lb_method', mapper.No
      op), ('protocol', 'protocol', mapper.Noop), ('subnet', 'subnet_id', ma
      pper.Resource('neutron.subnet')), ('project', 'tenant_id', mapper.Reso
      urce('project')), ('health_monitors', 'health_monitors', mapper.List(m
      apper.Resource('neutron.lb.health_monitor'))), ('is_enabled', 'admin_s
      tate_up', mapper.Noop), ('status', 'status', mapper.Noop),]